==> meta-0.1.0-20170515.000841-3.jar: index.html.out/cljs_deps.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.object', 'goog.math.Integer', 'goog.string.StringBuffer', 'goog.array', 'goog.math.Long']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../bidi/bidi.js", ['bidi.bidi'], ['goog.Uri', 'cljs.core', 'clojure.string']);
goog.addDependency("../schema/utils.js", ['schema.utils'], ['goog.string', 'cljs.core', 'goog.string.format', 'clojure.string']);
goog.addDependency("../schema/spec/core.js", ['schema.spec.core'], ['cljs.core', 'schema.utils']);
goog.addDependency("../schema/spec/collection.js", ['schema.spec.collection'], ['cljs.core', 'schema.spec.core', 'schema.utils']);
goog.addDependency("../schema/spec/variant.js", ['schema.spec.variant'], ['cljs.core', 'schema.spec.core', 'schema.utils']);
goog.addDependency("../schema/spec/leaf.js", ['schema.spec.leaf'], ['cljs.core', 'schema.spec.core']);
goog.addDependency("../schema/core.js", ['schema.core'], ['schema.spec.collection', 'cljs.core', 'schema.spec.core', 'schema.spec.variant', 'schema.spec.leaf', 'clojure.string', 'schema.utils']);
goog.addDependency("../javelin/core.js", ['javelin.core'], ['cljs.core', 'goog.object', 'goog.array']);
goog.addDependency("../cljsjs/development/jquery.inc.js", ['cljsjs.jquery'], []);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../cljs/reader.js", ['cljs.reader'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../hoplon/core.js", ['hoplon.core'], ['javelin.core', 'goog.Uri', 'cljs.core', 'goog.object', 'clojure.set', 'clojure.string', 'cljs.reader']);
goog.addDependency("../hoplon/jquery.js", ['hoplon.jquery'], ['cljsjs.jquery', 'cljs.core', 'hoplon.core']);
goog.addDependency("../bidi/schema.js", ['bidi.schema'], ['bidi.bidi', 'schema.core', 'cljs.core']);
goog.addDependency("../clojure/walk.js", ['clojure.walk'], ['cljs.core']);
goog.addDependency("../cuerdas/core.js", ['cuerdas.core'], ['goog.string', 'cljs.core', 'clojure.set', 'clojure.string', 'cljs.reader', 'clojure.walk']);
goog.addDependency("../hoplon/bidi.js", ['hoplon.bidi'], ['bidi.bidi', 'schema.core', 'javelin.core', 'hoplon.jquery', 'cljs.core', 'hoplon.core', 'bidi.schema', 'cuerdas.core']);
goog.addDependency("../app/routing.js", ['app.routing'], ['hoplon.bidi', 'cljs.core']);
goog.addDependency("../cljsjs/development/socket.io.inc.js", ['cljsjs.socket_io'], []);
goog.addDependency("../cljsjs/feathers/development/feathers.inc.js", ['cljsjs.feathers'], []);
goog.addDependency("../feathers/client.js", ['feathers.client'], ['cljsjs.jquery', 'cljs.core', 'cljsjs.feathers']);
goog.addDependency("../feathers/client/services.js", ['feathers.client.services'], ['cljs.core', 'feathers.client']);
goog.addDependency("../meta/client.js", ['meta.client'], ['cljs.core', 'goog.object', 'cljsjs.socket_io', 'feathers.client.services', 'feathers.client']);
goog.addDependency("../app/client.js", ['app.client'], ['cljs.core', 'meta.client']);
goog.addDependency("../app/index.js", ['app.index'], ['hoplon.bidi', 'app.routing', 'cljs.core', 'hoplon.core', 'app.client']);
goog.addDependency("../boot/cljs/main8928.js", ['boot.cljs.main8928'], ['cljs.core', 'app.index']);

==> meta-0.1.0-20170516.180826-4.jar: index.html.out/cljs_deps.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.object', 'goog.math.Integer', 'goog.string.StringBuffer', 'goog.array', 'goog.math.Long']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../bidi/bidi.js", ['bidi.bidi'], ['goog.Uri', 'cljs.core', 'clojure.string']);
goog.addDependency("../schema/utils.js", ['schema.utils'], ['goog.string', 'cljs.core', 'goog.string.format', 'clojure.string']);
goog.addDependency("../schema/spec/core.js", ['schema.spec.core'], ['cljs.core', 'schema.utils']);
goog.addDependency("../schema/spec/collection.js", ['schema.spec.collection'], ['cljs.core', 'schema.spec.core', 'schema.utils']);
goog.addDependency("../schema/spec/variant.js", ['schema.spec.variant'], ['cljs.core', 'schema.spec.core', 'schema.utils']);
goog.addDependency("../schema/spec/leaf.js", ['schema.spec.leaf'], ['cljs.core', 'schema.spec.core']);
goog.addDependency("../schema/core.js", ['schema.core'], ['schema.spec.collection', 'cljs.core', 'schema.spec.core', 'schema.spec.variant', 'schema.spec.leaf', 'clojure.string', 'schema.utils']);
goog.addDependency("../javelin/core.js", ['javelin.core'], ['cljs.core', 'goog.object', 'goog.array']);
goog.addDependency("../cljsjs/development/jquery.inc.js", ['cljsjs.jquery'], []);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../cljs/reader.js", ['cljs.reader'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../hoplon/core.js", ['hoplon.core'], ['javelin.core', 'goog.Uri', 'cljs.core', 'goog.object', 'clojure.set', 'clojure.string', 'cljs.reader']);
goog.addDependency("../hoplon/jquery.js", ['hoplon.jquery'], ['cljsjs.jquery', 'cljs.core', 'hoplon.core']);
goog.addDependency("../bidi/schema.js", ['bidi.schema'], ['bidi.bidi', 'schema.core', 'cljs.core']);
goog.addDependency("../clojure/walk.js", ['clojure.walk'], ['cljs.core']);
goog.addDependency("../cuerdas/core.js", ['cuerdas.core'], ['goog.string', 'cljs.core', 'clojure.set', 'clojure.string', 'cljs.reader', 'clojure.walk']);
goog.addDependency("../hoplon/bidi.js", ['hoplon.bidi'], ['bidi.bidi', 'schema.core', 'javelin.core', 'hoplon.jquery', 'cljs.core', 'hoplon.core', 'bidi.schema', 'cuerdas.core']);
goog.addDependency("../app/routing.js", ['app.routing'], ['hoplon.bidi', 'cljs.core']);
goog.addDependency("../cljsjs/development/socket.io.inc.js", ['cljsjs.socket_io'], []);
goog.addDependency("../cljsjs/feathers/development/feathers.inc.js", ['cljsjs.feathers'], []);
goog.addDependency("../feathers/client.js", ['feathers.client'], ['cljsjs.jquery', 'cljs.core', 'cljsjs.feathers']);
goog.addDependency("../feathers/client/services.js", ['feathers.client.services'], ['cljs.core', 'feathers.client']);
goog.addDependency("../meta/client.js", ['meta.client'], ['cljs.core', 'goog.object', 'cljsjs.socket_io', 'feathers.client.services', 'feathers.client']);
goog.addDependency("../app/client.js", ['app.client'], ['cljs.core', 'meta.client']);
goog.addDependency("../cljsjs/material-components/development/material-components.inc.js", ['cljsjs.material_components'], []);
goog.addDependency("../material_hl/core.js", ['material_hl.core'], ['goog.dom.classlist', 'javelin.core', 'cljs.core', 'hoplon.core', 'cljsjs.material_components']);
goog.addDependency("../material_hl/drawer.js", ['material_hl.drawer'], ['material_hl.core', 'cljs.core', 'hoplon.core']);
goog.addDependency("../material_hl/toolbar.js", ['material_hl.toolbar'], ['material_hl.core', 'cljs.core', 'hoplon.core']);
goog.addDependency("../meta/dom/mdc.js", ['meta.dom.mdc'], ['material_hl.drawer', 'material_hl.core', 'hoplon.bidi', 'javelin.core', 'material_hl.toolbar', 'cljs.core', 'hoplon.core']);
goog.addDependency("../meta/dom.js", ['meta.dom'], ['cljs.core', 'meta.dom.mdc']);
goog.addDependency("../app/index.js", ['app.index'], ['hoplon.bidi', 'app.routing', 'cljs.core', 'hoplon.core', 'app.client', 'meta.dom']);
goog.addDependency("../boot/cljs/main8930.js", ['boot.cljs.main8930'], ['cljs.core', 'app.index']);
